The number of algebraic cycles with bounded degree
Abstract.
Let be a projective scheme over a finite field. In this paper, we consider the asymptotic behavior of the number of effective cycles on with bounded degree as it goes to the infinity. By this estimate, we can define a certain kind of zeta functions associated with groups of cycles. We also consider an analogue in Arakelov geometry.
Introduction
Let be a projective scheme over a finite field and an ample line bundle on . For a non-negative integer , we denote by the number of all effective -dimensional cycles on with , where is the degree of with respect to given by
One of the main results of this paper is to give an estimate of as goes to the infinity, namely,
Theorem A (Geometric version).
- (1)
If is very ample, then there is a constant depending only on and such that for all .
- (2)
If , then .
As a consequence of the above theorem, we can define a certain kind of zeta functions of algebraic cycles as follows. We note that Weil’s zeta function is given by
accordingly we define a zeta function of -dimensional cycles on a polarized scheme over to be
Then, by the above theorem, we can see that is a convergent power series at the origin.
Further, using the same techniques, we can estimate the number of rational points defined over a function field. Let be a projective smooth curve over and the function field of . Let be a morphism of projective varieties over and an -ample line bundle on . Let be the generic fiber of . For , we define the height of with respect to to be
where is the Zariski closure of the image of . Then, we can see that, for a fixed , there is a constant such that
for all . Thus, a series
converges for all with . This is a local analogue of Batyrev-Manin-Tschinkel’s height zeta functions.
Moreover, let be a flat and projective scheme over the ring of integers of a number field and let be an ample line bundle on . Then, as a corollary of our estimates, we can see an infinite product
converges for all with , which looks like a generalization of the usual -functions.
The next purpose of this paper is to give an analogue in Arakelov geometry. Let be a projective arithmetic variety, i.e, a flat and projective integral scheme over . Let be an ample -hermitian -line bundle on . For a cycle of dimension on , the arithmetic degree of is defined by
For a real number , we denote by (resp. ) the number of effective cycles (resp. horizontal effective cycles) of dimension on with . Then, we have the following analogue.
Theorem B (Arithmetic version).
- (1)
There is a constant such that
for all .
- (2)
If , then .
Techniques involving the proof of Theorem B are much harder than the geometric case, but the outline for the proof is similar to geometric one. We have also the estimate of rational points defined over a finitely generated field over (cf. Theorem 6.1.1).
Finally, we would like to give hearty thanks to Prof. Mori, Prof. Soulé and Prof. Wan for their useful comments and suggestions for this paper.
1. Notations and Conventions
Here, we introduce notations and conventions in this paper.
(1.1).
For a point of a scheme , the residue field at is denoted by .
(1.2).
Let be a Noetherian scheme. For a non-negative integer , we denote by the set of all -dimensional integral closed subschemes on . We set
where . An element of (resp. ) is called an -dimensional cycle (resp. -dimensional effective cycle) on .
For a subset of , we denote and by and respectively. In this paper, we consider the following and as a subset of ; For a Zariski open set of , we set
For a morphism of Noetherian schemes with irreducible, we set
For simplicity, we denote , , and by , , and respectively. In order to show the fixed morphism , and are sometimes denoted by and respectively.
(1.3).
Let be a commutative ring with the unity. Let be the product of projective spaces over , that is,
If is UFD, then, for a divisor on , there is the unique sequence of non-negative integers and the unique section module such that , where is the projection to the -th factor. We denote by and call it the -th degree of . Moreover, for simplicity, we denote
by . Note that .
(1.4).
For a non-negative integer , we set
We assume . Let us consider the scheme over , where is a commutative ring. Let be the projection to the -th factor. For a subset of , we define as follows: If , then is the canonical morphism . Otherwise, we set with . Then, , i.e., . Note that .
(1.5).
Let us fix a basis of . The Fubini-Study metric of with respect to is given by
For a real number , the metric is denoted by . Moreover, the hermitian line bundle is denoted by .
(1.6).
Let and be real valued functions on a set . We use the notation ‘’ if there are positive real numbers and real numbers such that and for all .
2. The geometric case
The main purpose of this section is to find a universal upper bound of the number of effective cycles with bounded degree on the projective space over a finite field (cf. Theorem 2.3.3), namely,
Fix non-negative integers and . Then, there is a constant depending only on and such that the number of effective -dimensional cycles on with degree is less than or equal to .
First we consider a similar problem on the product of the projective line. The advantage of is that it has a lot of morphisms, so that induction on its dimension works well.
2.1. Preliminaries
Here let us prepare basic tools to count cycles.
Let be a sequence of sets. If it satisfies the following properties (1) – (4), then it is called a counting system.
- (1)
For each , there is a function .
- (2)
For each , there are maps and such that
for all .
- (3)
There is a function such that for all and and that, for and ,
- (4)
There is a function and a non-negative constant such that
for all .
Lemma 2.1.1.
If is a counting system as above, then
for all .
Proof. For with , by the property (2), we have and . Thus, by using (3) and (4),
Therefore, we get our lemma by using induction on .
The following lemma will be used to see the above property (3).
Lemma 2.1.2.
Let and be projective schemes over a field . Let and be the projection to the first factor and the projection to the second factor respectively. Let (resp. ) be closed points of (resp. ). Let us fix an effective -cycle and an effective -cycle . Then, the number of effective -cycles on with and is less than or equal to , where and .
Proof. Let ’s () be all closed points of . Then, an effective -cycle on with and can be written by the form . Hence,
and
Thus,
Therefore, the number of effective -cycles on with and is less than or equal to . Here note that
Moreover, for . Hence,
Thus, we get our lemma.
The following lemma will be also used to count cycles.
Lemma 2.1.3.
Let be a finite morphism of normal integral schemes. Let be an effective cycle on , where ’s are integral. Then the number of effective cycles on with is less than or equal to .
Proof. We denote by the number of effective cycles on with . Let be all integral subschemes lying over . Then, . Let be an effective cycle on with . Then, we can set . Since , the number of possible ’s is at most . Therefore,
Here note that for . Hence we get our lemma.
2.2. Cycles on
Let us begin with the case of divisors.
Proposition 2.2.1.
Let be non-negative integers. Then
Proof. In the following, the symbol is an effective divisor on .
In order to proceed with induction, the following lemmas are very useful.
Lemma 2.2.2.
Let and be morphisms of projective schemes over . We assume that is integral and of dimension . Let and be the projections to the first factor and the second factor respectively. Fix and (for the definition of and , see (1.2)).
- (1)
Assume . Let be nef line bundles on , nef line bundle on , and nef line bundles on such that and are nef for all and that . Then,
where (resp. ) is the number of irreducible components of (resp. ).
- (2)
Assume , so that for some positive integer . Then,
Proof. (1) We set and . Then,
| (2.2.2.1) |
In the same way,
| (2.2.2.2) |
Thus,
Moreover, note that
Thus, the above inequalities (2.2.2.1) and (2.2.2.2) imply
and
Therefore, considering , and over the generic point of , Lemma 2.1.2 implies our assertion.
(2) We set and . Then,
and
Thus, in the same way as in (1), we get our assertion.
Using the above lemma, we have the following.
Proposition 2.2.3.
There is a constant depending only and such that
for all .
Proof. First we assume . Let us see
for . We prove this by induction on . If , then our assertion follows from Proposition 2.2.1, so that we assume . Let be the projection given by . For a fixed , let us estimate the number of . We set . For with , let be the decomposition of effective -cycles with (). Then, and the degree of in is . Thus, the possible number of is less than or equal to . Thus,
Therefore, since , using the hypothesis of induction,
Next we assume . For a subset of with , let us consider the morphism (for the definition of , see (1.4)). We denote by the set of effective cycles on generated by -dimensional subvarieties which dominates via . Then, it is easy to see that
Thus, since
it is sufficient to see that there is a constant depending only on and such that
for all . By re-ordering the coordinate of , we can find an automorphism
with and . Thus, we may assume that . We denote by . Let be the projection to the -th factor. For , we set
and for . Let and be morphisms given by and , namely,
Here, and are given by
Then, since
and
it is easy to see that and . Note that the diagram
is a fiber product. Thus, by Lemma 2.2.2, if we set , then, for and ,
Here,
Thus, by Proposition 2.2.1, if we set , then
Therefore, by Lemma 2.1.1,
for all .
Moreover, we have the following variant of Proposition 2.2.3.
Proposition 2.2.4.
Let , and be positive integers with . Let be the morphism given in (1.4). Let be the projection to the -th factor. We set and . Then, for a fixed , there is a constant such that
for all .
Proof. We set
Then,
Thus, it is sufficient to show that there is a constant
for all . Re-ordering the coordinate of , we may assume that . We denote by . Let and be morphisms given by and , i.e., and . Then,
| (2.2.4.1) |
Here, for , we set
Let be a map given by . Then, by (2.2.4.1), we have maps and given by and . Moreover, and for all . As in Lemma 2.2.2, we denote by the number of irreducible components of a cycle . Then, for , it is easy to see that . Further,
Thus, by Lemma 2.2.2, for and ,
Thus, if we set , then
Here let us estimate . In this case, is a divisor on . Thus,
and
Therefore, for and for . Hence, by Proposition 2.2.1, if we set for some constant , then
for .
Remark 2.2.5.
The following are remarks for Proposition 2.2.4.
- (1)
, where the subscript means the restriction of an object on to the generic fiber of .
- (2)
If we set , then, for a fixed , there is a constant such that
for all . ( Note that . Thus, and .)
2.3. Cycles on a projective variety over a finite field
Here we consider the main problem of this section. Let us begin with two lemmas.
Lemma 2.3.1.
Let be a field. Let be the birational map given by
Let be the boundary of , that is, . For , we denote by the strict transform of by (For the definition of , see (1.2)). Then,
for all .
Proof. Let ( be the graph of the rational map . Let and be the morphisms induced by the projections and respectively. Here we claim that there is an effective Cartier divisor on such that (1) and (2) . Let ( be the graph of the rational map given by
Let and be the morphisms induced by the projections and respectively. Let be the projection to the -th factor. Moreover, let be the morphism induced by . Consequently, we have the following commutative diagram:
Note that is the blowing-up by the ideal sheaf generated by and . Thus there is an effective Cartier divisor on with and . Thus if we set , then
Hence we get our claim.
For , let be the strict transform of by . Then, by using the projection formula,
Moreover, by the following Lemma 2.3.2
Thus, using the projection formula for , we get our lemma because .
Lemma 2.3.2.
Let be a projective variety over a field and nef line bundles on . If is pseudo-effective for , then
Proof. We set . Then
Thus, we get our lemma.
Theorem 2.3.3.
There is a constant depending only on and such that
for all .
Proof. We prove this theorem by induction on . Let us consider the birational map given by
We set . For , we denote by the strict transform of by . Then, by Lemma 2.3.1,
Moreover, note that if for , then . Therefore
Here, by Proposition 2.2.3, there is a constant depending only and such that
Hence, we have
| (2.3.3.1) |
On the other hand, since ,
Thus, using the hypothesis of induction, if we set , then we have our theorem.
Corollary 2.3.4.
Let be a projective variety over a finite field and a very ample line bundle on . Then, for every integer with , there is a constant depending only on and such that
Proof. Since is very ample, there is an embedding with , where . Thus, it follows from Theorem 2.3.3.
Finally, let us consider a lower bound of effective cycles with bounded degree.
Proposition 2.3.5.
Let be a projective variety over a finite field and an ample line bundle on . Then, for every integer with ,
Proof. Take -dimensional subvariety of . Then,
Thus, we may assume . Here, note that
where . Since is ample, . Thus we get our proposition.
2.4. Northcott’s type
Let be a -dimensional projective variety over . We assume that . Let be a nef and big line bundle on . Let be a projective variety over and a surjective morphism over . Let be a nef line bundle on . In the following, the subscript of an object on means its restriction on the generic fiber of .
Theorem 2.4.1.
If is ample, then, for a fixed , there is a constant such that
for all .
Proof. Step 1: We set and . Let be the projection to the -th factor. Similarly, let be the projection to the -th factor. Here is given the natural projection , namely, . Moreover, we set and . In this situation, we have our theorem by Proposition 2.2.4 and Remark 2.2.5.
Step 2: Let us consider a case where , is given by the projection to the first factor and . Here is the natural projection. By virtue of Noether’s normalization theorem, there is a dominant rational map . Let the following diagram
be the graph of the rational map . Here we set , and . Let , , , and be the natural projections. Moreover, we set and .
Let be a homomorphism given by the strict transform in terms of . Further, let be the homomorphism given by the push forward of cycles. Since is nef and big, there is a positive integer such that . Then, by Lemma 2.3.2,
Moreover,
where the subscripts and means the restrictions of objects to the generic fibers and respectively.
For a fixed , we claim that
Let be the maximal Zariski open set of such that is finite over . We set . Then, the natural homomorphisms
are bijective, where and . Thus, by virtue of Lemma 2.1.3, if we set , then
On the other hand,
Therefore, we get our claim.
Hence, by the above observations and Step 1, we have our case.
Step 3: Next let us consider a case where , is given the natural projection and . Here is the natural projection. We prove our theorem of this situation by induction on . If , then our assertion is obvious. Thus we assume that . Let the following diagram
be the graph of the rational map given by
Then, as in Lemma 2.3.1, there is an effective Cartier divisor on such that and . Here we set and , where is the natural projection. Moreover, is given by the natural projection. Then, for , by Lemma 2.3.2,
where is the strict transform of by . Further,
where and means the restriction of objects on and to the generic fibers and respectively. Here . Thus, by hypothesis of induction and Step 2, we have our case.
Step 4: Finally we consider a general case. Clearly we may assume that is very ample. Thus, there are a positive integer and a subvariety of with the following properties:
- (1)
Let (resp. ) be the projection to the first factor (resp. the second factor). There is a non-empty Zariski open set of such that is isomorphic to over . We denote this isomorphism by .
- (2)
If we set , then .
Let
be the graph of the rational map induced by . We denote by . By the property (2),
Thus, we can find an ample line bundle on such that
Let us choose a non-zero element of
Since , by Lemma 2.3.2,
where is the strict transform of by . Moreover,
Therefore, by Step 3, we get our theorem.
2.5. Geometric height functions defined over a finitely generated field over
Let be a finitely generated field over with . Let be a projective variety over and a line bundle on . Here we fix a projective variety and a nef and big line bundle on such that the function field of is . We choose a pair with the following properties:
- (1)
is a projective variety over and there is a morphism over such that is the generic fiber of .
- (2)
is a -line bundle on (i.e., ) such that coincides with in .
The pair is called a model of .
For , let be the closure of the image . Then, the height function of with respect to and is defined by
It is not difficult to see that if is another model of , then there is a constant such that
for all (cf. [5, the proof of Proposition 3.3.3]). Thus, the height function is uniquely determined modulo bounded functions. In this sense, we denote the class of modulo bounded functions by . As a corollary of Theorem 2.4.1, we have the following.
Corollary 2.5.2.
Let be a representative of . If is ample, then, for a fixed , there is a constant such that
for all .
3. Preliminaries for the arithmetic case
3.1. Arakelov geometry
In this paper, a flat and quasi-projective integral scheme over is called an arithmetic variety. If it is smooth over , then it is said to be generically smooth.
Let be a generically smooth arithmetic variety. A pair is called an arithmetic cycle of codimension if is a cycle of codimension and is a current of type on . We denote by the set of all arithmetic cycles on . We set
where is the arithmetic linear equivalence.
Let be a -hermitian line bundle on . Then, a homomorphism
is define by
where is a rational section of and is a current given by .
Here we assume that is projective. Then we can define the arithmetic degree map
by
Thus, if -hermitian line bundles are given, then we can get the number
which is called the arithmetic intersection number of .
Let be a projective arithmetic variety. Note that is not necessarily generically smooth. Let be -hermitian line bundles on . Choose a birational morphism such that is a generically smooth projective arithmetic variety. Then, we can see that the arithmetic intersection number
does not depend on the choice of the generic resolution of singularities . Thus, we denote this number by
Let be a morphism of projective arithmetic varieties. Let be -hermitian line bundles on , and -hermitian line bundles on . If , then the following formula is called the projection formula:
| (3.1.1) |
where the subscript means the restriction of line bundles to the generic fiber of .
Let be -hermitian line bundles on a projective arithmetic variety . Let be an -dimensional integral closed subscheme on . Then, is defined by
Note that if is lying over a prime with respect to , then
Moreover, for an -dimensional cycle on , is given by
Let be a morphism of projective arithmetic varieties. Let be -hermitian line bundles on . Then, as a consequence of (3.1.1), we have
| (3.1.2) |
for all -dimensional cycles on .
3.2. The positivity of -hermitian -line bundles
Let be a projective arithmetic variety and a -hermitian -line bundle on . Let us consider several kinds of the positivity of -hermitian -line bundles.
ample: We say is ample if is ample on , is positive form on , and there is a positive number such that is generated by the set .
nef: We say is nef if is a semipositive form on and, for all one-dimensional integral closed subschemes of , .
big: is said to be big if and there is a non-zero section of with for some positive integer .
-effective: is said to be -effective if there is a positive integer and a non-zero with .
pseudo-effective: is said to be pseudo-effective if there are (1) a sequence of -effective -hermitian -line bundles, (2) -hermitian -line bundles and (3) sequences of rational numbers such that
in and for all . If is pseudo-effective for -hermitian -line bundles on , then we denote this by .
of surface type: is said to be of surface type if there are a morphism of projective arithmetic varieties and a -hermitian -line bundle on such that (i.e. is a projective arithmetic surface), is nef and big, and that in .
Here let us consider three lemmas which will be used later.
Lemma 3.2.3.
Let be a projective arithmetic variety. Then, we have the following.
- (1)
Let be nef -hermitian -line bundles on . If is pseudo-effective for every , then
- (2)
Let be an effective cycle of dimension and let be nef -hermitian -line bundles on such that, for each , there is a non-zero global section with . Let be the irreducible decomposition as a cycle. If for all , then
Proof. (1) This lemma follows from [5, Proposition 2.3] and the following formula:
(2) This is a consequence of (1).
Lemma 3.2.4.
Let be a projective arithmetic variety and an integer with . Let be projective arithmetic surfaces (i.e. -dimensional projective arithmetic varieties) and () surjective morphisms. Let be -hermitian -line bundles on respectively with (), and let be -hermitian -line bundles on . We set and . Then,
Proof. First of all,
Claim 3.2.4.1.
If and
then there are such that , and for all .
Clearly, for all . Thus, there is with . Suppose that for some . Then,
Thus, using the projection formula with respect to ,
where means the restriction of line bundles to the generic fiber of . Here is projective curve. Thus, we can see
This is a contradiction. Hence, we get our claim.
By the above claim, it is sufficient to see that
By the projection formula with respect to ,
Moreover, using the projection formula with respect to again,
Thus, we get our lemma.
Finally let us consider the following technical lemma.
Lemma 3.2.5.
Let be the birational map given by
Let be the boundary of , that is, . Let be a projective arithmetic variety and nef -hermitian line bundles on , where . For , we denote by the strict transform of by (For the definition of , see (1.2)). Let us fix a non-negative real number . Then,
for all , where and (resp. and ) are the projections to the first factor (the second factor). Note that in the case , we do not use the nef -hermitian line bundles .
Proof. Let ( be the graph of the rational map . Let and be the morphisms induced by the projections. Here we claim the following:
Claim 3.2.5.1.
There are an effective Cartier divisor on , a non-zero section and a -metric of such that
- (1)
, ,
- (2)
, and that
- (3)
for all .
Let ( be the graph of the rational map given by
Let and be the morphisms induced by the projections and respectively. Let be the projection to the -th factor. Moreover, let be the morphism induced by . Consequently, we have the following commutative diagram:
Note that is the blowing-up by the ideal sheaf generated by and . Thus there is an effective Cartier divisor on with and . Let be the canonical section of . We choose -metric of with
Let be a coordinate of . Then, . Thus,
which implies
because . Therefore, for all . We set and give a -metric to with
Thus, if we set , then , and for all . Moreover, we have
Hence we get our claim.
For , let be the strict transform of by . Let and be the projections to the first factor and the second factors respectively. Then, by using the projection formula,
Moreover, by virtue of (2) of Lemma 3.2.3,
Thus, using the projection formula for , we get our lemma because .
3.3. Polarization of a finitely generated field over
Let be a finitely generated field over with , and let be a projective arithmetic variety such that is the function field of . Here we fix several notations.
polarization: A collection of and nef -hermitian -line bundles on is called a polarization of .
big polarization: A polarization is said to be big if are nef and big.
fine polarization: A polarization is said to be fine if there are a generically finite morphism of projective arithmetic varieties, and -hermitian -line bundles on such that are of surface type, for all , and that is nef and big.
Let us consider the following proposition.
Proposition 3.3.6.
If a polarization is fine, then there are generically finite morphisms and with the following property: for any real number , there are positive rational numbers such that
for all , where is the projection to the -th factor.
Proof. By the definition of fineness, there are a generically finite morphism of projective arithmetic varieties, morphisms () of projective arithmetic varieties, and nef and big -hermitian -line bundles on () such that ’s are arithmetic surfaces, for all , and that is nef and big. Here, there are dominant rational maps for . Replacing and ’s by their suitable birational models, we may assume ’s are morphisms. Let be a morphism given by . Let us fix a real number . Then, since is nef and big, there is a positive rational number with . Thus,
Finally, we need to see that is generically finite. For this purpose, it is sufficient to see that is nef and big on . Indeed, we can find a positive rational number such that is ample over for all . Thus,
is semiample on . Thus, is nef and big because is nef and big.
Finally we would like to give a simple sufficient condition for the fineness of a polarization. Let be a number field, and the ring of integer in . Let be projective and flat integral schemes over whose generic fibers over are geometrically irreducible. Let be the function field of and the transcendence degree of over . We set and . Then, the function field of is the quotient field of , which is denoted by , and the transcendence degree of over is . For each (), let be nef and big -hermitian -line bundles on . We denote by the projection to the -th factor. Then, we have the following.
Proposition 3.3.7.
A polarization of given by
is fine. In particular, a big polarization is fine.
Proof. Since there is a dominant rational map by virtue of Noether’s normalization theorem, we can find a birational morphism of projective integral schemes over and a generically finite morphism . We set , and . Let be a -hermitian line bundle on given by . Note that is nef and big. Then, since is big, there is a positive integer with (cf. [5, Proposition 2.2]), that is, . Thus, we get our proposition.
3.4. Height functions over a finitely generated field
Let be a finitely generated field over with , and let be a polarization of . Let be a geometrically irreducible projective variety over and an ample line bundle on . Let us take a projective integral scheme over and a -hermitian -line bundle on such that is the generic fiber of and is equal to in . The pair is called a model of . Then, for , we define to be
where is the Zariski closure in of the image , and is the canonical morphism. By virtue of [5, Corollary 3.3.5], if is another model of over , then there is a constant with for all . Hence, we have the unique height function modulo the set of bounded functions. In the case where , if we set
for , then on .
Let be a projective arithmetic variety with . Let be -hermitian -line bundles of surface type on . By its definition, for each , there are a morphism of flat and projective integral schemes over and a -hermitian -line bundle on such that , is nef and big, and that in . We set and
Let be the function field of . Here we consider several kinds of polarizations of as follows:
Let be a geometrically irreducible projective variety over , and an ample line bundle on . Let be a model of over . Then, for all ,
| (3.4.1) |
Indeed, by Lemma 3.2.4,
where is the canonical morphism. Moreover,
On the other hand,
Thus, we obtain
Therefore, we get (3.4.1).
Using (3.4.1), we can find a constant such that
| (3.4.2) |
for all because there is a positive integer such that
for every .
Proposition 3.4.3.
Let be a geometrically irreducible projective variety over , and an ample line bundle on . Let and be fine polarizations of . Then on (For the notation , see (1.6)).
Proof. It is sufficient to see that there are a positive real number and a real number such that . We set and . Since is fine, by Proposition 3.3.6, there are generically finite morphisms and of flat and projective integral schemes over , and nef and big -hermitian -line bundles on such that for all , where is the projection to the -th factor. Changing if necessarily, we may assume that there is a generically finite morphism .
Let us consider polarizations
and compare with (resp. with ). By virtue of the projection formula, we may assume that and .
3.5. Comparisons of norms of polynomials
Let be the ring of -variable polynomials over . We define norms and of as follows:
Moreover, the degree of with respect to the variable is denoted by .
First of all, we have obvious inequalities:
| (3.5.1) |
We set
Note that
| (3.5.2) |
For , we set
| (3.5.3) |
where ’s are the -forms on given by
Let us begin with the following proposition.
Proposition 3.5.4.
For , we have the following.
- (1)
.
- (2)
.
For the proof of (2), we set
Then,
For , let us consider a holomorphic map
given by , where is a map given by and . Then, since ,
Here we can find such that
and . Note that
for all . Therefore,
Thus, we have
Hence, by the lemma below (Lemma 3.5.5), we can conclude
Lemma 3.5.5.
For all ,
Proof. Let us begin with the following sublemma:
Sublemma 3.5.6.
Let be a differential manifold and a volume form on with . Let be a -function with . Let be a real valued function on . If and are integrable on , then .
Proof. We set . Since the second derivative of is non-negative, we can see
for all . Therefore, we get
On the other hand, the left hand side of the above inequality is zero, and the right hand side is . Thus, we have our desired inequality.
Let us go back to the proof of Lemma 3.5.5. Applying the above lemma to the case ,
We set for all . Then
It is easy to see that
if . Moreover,
Thus, it is sufficient to see that
for all . We set , then
If , then the above integral is . Further if , then
Next let us consider the following proposition.
Proposition 3.5.7.
For ,
Proof. For , the -th entry of is denoted by . A partial order ‘’ on is defined as follows:
Moreover, for , the monomial is denoted by .
Let us fix two non-zero polynomials
We set , and
First, we note that, for a fixed ,
On the other hand,
Thus,
For , we denote by the coefficient of the highest terms of as a polynomial of , that is, if we set
then . Note that and . For an element of the -th symmetric group , we set
Then we have the following proposition.
Proposition 3.5.8.
For a non-zero ,
In particular, if , then
Proof. Changing the order of variables, it is sufficient to see that
We prove this by induction on . First we assume . Then, for ,
Next we consider a general . By the hypothesis of induction, we can see that
as a function with respect to . Thus,
4. The number of arithmetic divisors
Here let us consider several problems concerning the number of arithmetic divisors with bounded arithmetic degree.
Proposition 4.1.
Let be the projection to the -th factor. Let us fix a positive real number , a subset of and a function . For a divisor on , we set
Then, there is a constant depending only on and such that
for . (Note that in the case where , no condition on is posed.)
Proof. Fix a basis of of the -th factor of . We denote by the set of homogeneous polynomials of multi-degree . Then,
Let be an effective divisor on with (). Then there is
with . Let us evaluate
in terms of , namely,
where (). We set . Then,
Note that
Thus,
| (4.1.1) |
On the other hand, by Proposition 3.5.4,
Thus,
| (4.1.2) |
We assume that . Then, since
by (4.1.1),
| (4.1.3) |
Moreover, using (4.1.2), if , then
Thus, if we set
then
| (4.1.4) |
Therefore,
Hence if we set
then we can see
Note that in the case where , the number in the above inequality is treated as . Thus, we get our lemma.
Proposition 4.2.
Let us fix a positive real number . For a divisor on , we set
where is the projection to the -th factor. Let be closed points of . Then, we have the following:
- (1)
- (2)
We assume . Then
where is the set of all effective divisors on generated by prime divisors flat over .
Proof. Let us fix a coordinate of the -th factor of . Then, note that
We set . Then, in for all . Since is ample, there is a positive integer with , where is the maximal ideal at . Thus, the homomorphism
is surjective. Hence, there is with for all . Clearly, we may assume that is primitive as a polynomial in .
For and , we set . Note that for all . Thus, we get a map
given by . Here we claim that is injective. Indeed, if , then or . Clearly, if , then , so that we assume . Then . Since is primitive, so is . This is a contradiction.
We set . Let us choose a positive number with
Claim 4.2.1.
If , then .
We set and . Then . By (4.1.1),
Thus, using (2) of Proposition 3.5.4,
On the other hand, using Lemma 3.5.7 and ,
Therefore, since , we have
Let us go back to the proof of our proposition. Since is a free abelian group of rank ,
Therefore, by the above claim,
Thus, we get (1).
From now, we assume . We denote by (resp. ) the set
For , let be the unique decomposition such that is horizontal over and is vertical over . Note that , and . Thus, and . Therefore, we have a map
given by . Since for , is surjective. Here let us consider a fiber for . First of all, an element has a form
Since , we can see that . Thus,
Hence, we get
5. The arithmetic case
5.1. Arithmetic cycles on the products of
Here let us consider the number of cycles on . Let us begin with the following lemma.
Lemma 5.1.1.
Let and be morphisms of projective arithmetic varieties. We assume that is of dimension . Let be nef -hermitian line bundles on , nef -hermitian line bundles on , and nef -hermitian line bundles on such that and are nef for all and that . Let and be the projections to the first factor and the second factor respectively. Fix and (for the definition of and , see (1.2)). Then,
where (resp. ) is the number of irreducible components of (resp. ).
Proof. We set and . Then,
| (5.1.1.1) |
In the same way,
| (5.1.1.2) |
Thus, in the same way as in Lemma 2.2.2, we have our assertion.
Proposition 5.1.2.
Let us fix a positive real number . Let be the projection to the -th factor. We set . For , we denote by the set of all effective cycles on generated by -dimensional integral closed subschemes of which dominate by the canonical morphism . Then, there is a constant such that
for all .
Proof. We set . Then, it is easy to see that
where is the morphism given in (1.4). Thus, it is sufficient to show that there is a constant such that
for all . By re-ordering the coordinate of , we may assume that . We denote by . We set
Let us see that is a counting system. First we define to be
Let and be the morphisms given by and . Then, we have maps and defined by and . Here, it is easy to see that
for all . Moreover, by Lemma 5.1.1, if we set
and
then
for all and . Further, by Proposition 4.1, if we set
for some constant , then
for all . Thus, we can see that is a counting system. Therefore, by virtue of Lemma 2.1.1, we get our proposition.
Proposition 5.1.3.
Let be the set of effective cycles on generated by -dimensional integral subschemes which are not flat over . Then, there is a constant depending only on and such that
for .
Proof. For simplicity, we denote and by and respectively. Let be the canonical morphism. Let be a positive integer and the prime decomposition of . We set . Then,
Let be a constant as in Proposition 2.2.3. We set . Note that for all primes . Thus,
Therefore,
Thus, we get the proposition.
Theorem 5.1.4.
For all non-negative integers and with , there is a constant such that
for all .
As a variant of Proposition 5.1.2, we have the following:
Proposition 5.1.5.
Let us fix a positive real number . Let and be non-negative integers with . Let be the morphism as in (1.4). Let be the projection to the -th factor. For an integer with , we denote by the set of all effective cycles on generated by -dimensional integral closed subschemes of which dominate by . We set
for . Let be the function field of . For , we denote by the degree of in the generic fiber of with respect to . Then, for a fixed , there is a constant such that
for all .
Proof. We set
Then, it is easy to see that
Thus, it is sufficient to see that, for each , there is a constant such that
for all . By changing the coordinate, we may assume that . Here we denote by . For , we set
Let and be morphisms given by and . Then, since
and
we have maps and given by and . Moreover, we set
for . Then, it is easy to see that
for all . Note that
Thus, by Lemma 5.1.1, if we set
and
then
for all and . Further, in the case where ,
Therefore, by Proposition 4.1, there is a constant such that
for all . Hence, by Lemma 2.1.1, there is a constant such that
for all . Thus, we get our assertion.
5.2. Upper estimate of cycles with bounded arithmetic degree
Here let us consider the following theorem, which is one of the main results of this paper.
Theorem 5.2.1.
Let us fix a positive real number . For all non-negative integers with , there is a constant such that
for all .
Proof. Let us consider the birational map given by
We set . For , we denote by the strict transform of by (for the definition of , see (1.2)). Then, by applying Lemma 3.2.5 in the case ,
Moreover, if for , then . Therefore,
| (5.2.1.1) |
On the other hand, since ,
| (5.2.1.2) |
Thus, using (5.2.1.1), (5.2.1.2), Theorem 5.1.4 and the hypothesis of induction, we have our theorem.
Corollary 5.2.2.
Let be a projective arithmetic variety and an ample -hermitian line bundle on . For all non-negative integers with , there is a constant such that
for all .
Proof. Since is projective over , there is an embedding over . We fix a positive real number . Then, there is a positive integer such that is ample. Thus,
for all . Thus, our assertion follows from Theorem 5.2.1.
5.3. Lower bound of the number of arithmetic cycles with bounded degree
Here we consider the lower bound of the number of cycles.
Theorem 5.3.1.
Let be a projective arithmetic variety and an ample -hermitian line bundle on . Then, for ,
Moreover, if , then
Proof. Choose a closed integral subscheme of such that and is flat over . First, we assume that . Then, the canonical morphism is finite. For ,
Thus,
Note that
Thus,
Therefore,
From now on, we assume that . Since
we may assume that .
Let us take a birational morphism of projective arithmetic varieties such that there is a generically finite morphism , where . We set on for some positive real number . Let us choose a positive rational number such that there is a non-zero section with . Let be a Zariski open set of such that is an isomorphism over . Moreover, let be the non-flat locus of . Let
be the irreducible decomposition. Choose a closed point of for each . Then, by Proposition 4.2 and Remark 4.3,
Let be an element of with for all . First, we claim that is horizontal over . Assume the contrary, that is, contains a vertical irreducible component . Then, , which implies . Thus, there is with . Hence,
which contradicts the assumption .
By the above claim, we can consider a map
given by . Here we claim that is injective. We assume that . Since for and all , no component of is contained in . Thus, we have . Hence
Therefore, .
Let be an element of with for all . Since no component of is contained in , we can see
Thus
Therefore, we get our theorem.
6. The arithmetic case with bounded geometric degree
6.1. Northcott’s type in the arithmetic case
The purpose of this subsection is to prove the following theorem, which is a kind of refined Northcott’s theorem.
Theorem 6.1.1.
Let be a morphism of projective arithmetic varieties. Let be the function field of . Let be a fine polarization of , where . Let be a nef -hermitian line bundle on such that is ample. For an integer with , as in (1.2), let be the set of effective cycles on generated by integral closed -dimensional subschemes on with . We denote by the set of effective cycle with
Then, for a fixed k, there is a constant such that
for all .
Proof. First, let us consider a case where , is the natural projection and , where is the natural projection. Since the polarization is fine, by Proposition 3.3.6, there are generically finite morphisms and of projective arithmetic varieties, and positive rational numbers such that for all , where is the projection to the -th factor.
We set , and . Let and be the projections to the first factor and and the projections to the last factor. Here we claim the following.
Claim 6.1.1.1.
Let be the function field of . We denote by the set of effective cycles with
and
where . Then, for a fixed k, there is a constant such that
for all .
Fixing , we prove this lemma by induction on . If , then the assertion is trivial, so that we assume . Let be the rational map given by
We set and . Moreover, let be the projection to the last factor, and the projection to the -th factor. We set
For (i.e. and any component of is not contained in ), let be the strict transform of via . Then, Lemma 3.2.5 and Lemma 2.3.1,
and
On the other hand, . Thus, by the hypothesis of induction and Proposition 5.1.5, we have our claim.
We can define a homomorphism
with as follows: Let be the locus of points of over which is flat. We set . Then, for , no component of is contained in . Thus, is defined by the Zariski closure of . By virtue of ,
Thus, in order to prove the theorem in our case, we may assume that . Then,
Thus, by the above Claim, it is sufficient to see the following: For a fixed on , the number of effective cycles on with is less than or equal to . For, let be the irreducible decomposition. Then by Lemma 2.1.3, the above number is less than or equal to . On the other hand, we can see
Thus, we get the theorem in our case.
Let us go back to the proof of the theorem in a general case. Replacing by a positive multiple of it, we may assume that is very ample. Thus we have an embedding with . Let be the Zariski closure of in and the induced morphism. Let be the projection to the first factor and . Then there are birational morphisms and of projective arithmetic varieties. We set . Let be an ample line bundle on such that is generated by global sections. Thus there is a non-zero global section . Since , we can see that . We choose a metric of with . For , let be the strict transform of by and . Then,
Moreover,
Thus, we may assume that there is an embedding and . Therefore we get our Theorem.
6.2. The number of rational points over a finitely generated field
Let us consider the polarization
of , where is the projection to the -th factor. is called the standard polarization of . First, let us see the following lemma.
Lemma 6.2.1.
(See 3.4 for the definition .)
Proof. We set for . Clearly we may assume . Let be the closure of in . We set . Then
| (6.2.1.1) |
Let be a -valued point of . Then, there are such that and are relatively prime and . Thus, by (6.2.1.1)
Let be a positive number with . We set
(See (3.5.3) for the definition .)
First we claim that for all . If , then the assertion is obvious. We assume that . Then,
Next we claim that
For this purpose, we may assume that . Moreover, note that for . Thus, using (3.5.1) and Proposition 3.5.4,
By the second claim,
Thus, we get our lemma by the first claim.
Theorem 6.2.2.
Let be a finitely generated field over , and a fine polarization of . Let be a projective variety over and an ample line bundle on . Then
for all , where .
Proof. This is a consequence of Theorem 6.1.1.
Theorem 6.2.3.
Let be a finitely generated field over and a fine polarization of . Then,
where .
7. Zeta functions of algebraic cycles
In this section, we would like to propose a kind of zeta functions arising from the number of algebraic cycles. First let us consider a local case, i.e., the case over a finite field.
7.1. Local case
Let be a projective variety over a finite field and an ample line bundle on . For a non-negative integer , we denote by the number of all effective -dimensional cycles on with . We define a zeta function of -dimensional cycles on a polarized scheme over to be
Then, we have the following:
Theorem 7.1.1.
is a convergent power series at the origin.
Proof. First note that . Moreover, if we choose with very ample, then, by Corollary 2.3.4, there is a constant with . Thus,
where . Therefore, if , then
Thus, we get our theorem.
See Remark 7.4.6 for Wan’s zeta functions. Next, let us consider height zeta functions in the local case, which is a local analogue of Batyrev-Manin-Tschinkel’s height zeta functions (cf. [1]).
Theorem 7.1.2.
Let be a finitely generated field over a finite field with . Let be a projective variety over and a ample line bundle on . Let be a representative of the class of height functions associated with as in 2.5. Then, for a fixed , a series
converges absolutely and uniformly on the compact set in for some .
Proof. We set
for and
Then, by Corollary 2.5.2, there is a constant such that for all .
Thus, we have our assertion.
7.2. Global case
Let be a number field and the ring of integers in . Let be a flat and projective scheme over and an -ample line bundle on . For , we denote by the fiber of at . Here let us consider an infinite product
for . Then, we have the following:
Theorem 7.2.3.
There is a constant such that the infinite product converges absolutely and uniformly on the compact set in .
Proof. Since , replacing by for some positive number , we may assume that is very -ample. For non-negative integer , we set
Then,
We denote by . We set . Then, for each , we have an embedding with . Thus, by Theorem 2.3.3, there is a constant depending only on and with for all . Thus, for with ,
Therefore, we have
Hence, we get our theorem by the criterion of the convergence of infinite products.
7.3. Arithmetic case
Next let us consider an analogue in Arakelov geometry. Let be a projective arithmetic variety and an ample -hermitian -line bundle on . For an effective cycle of -dimension, the norm of is defined by
Then, the zeta function of for cycles of dimension is defined by
Theorem 7.3.4.
There is a constant such that the above converges absolutely and uniformly on the compact set in .
Proof. We denote the set of all -dimensional effective cycles on with . By Corollary 5.2.2, there is a constant such that
for all . We choose a positive constant with
for all . Moreover, for a real number , we set . Note that if , then . Thus, for with ,
Thus, we get our theorem.
7.4. Remarks
Here let us discuss remarks of the previous zeta functions. The first one is the abscissa of convergence of zeta functions.
Remark 7.4.5.
Let be an index set and a sequence of real numbers such that the set is finite for every real number . Then the abscissa of convergence of the Dirichlet series
is given by
Let be a projective scheme over and an ample line bundle on . Moreover, let be a projective arithmetic variety and an -hermitian line bundle on . We denote by (resp. ) the abscissa of convergence of (resp. ). Then, and are given by
and
respectively.
For example, let be an -dimensional projective scheme over with , where is ample. Then,
Remark 7.4.6.
Let be a projective variety over a finite field and an ample line bundle on . As before, the number of all effective -dimensional cycles on with is denoted by . In [9], Wan defined a zeta function by
He proved is -adic analytic and proposed several kinds of conjectures. Of course, is never analytic as -valued functions if . In order to get classical analytic functions, we need to replace by .
Appendix A. Bogomolov plus Lang in terms of a fine polarization
Theorem A.1 ([5, Theorem 4.3]).
We assume that the polarization is fine. Let be a geometrically irreducible projective variety over , and an ample line bundle on . Then, for any number and any positive integer , the set
is finite.
Theorem A.2 ([6, Theorem A]).
We assume that the polarization is fine. Let be an abelian variety over , and a symmetric ample line bundle on . Let
be a paring given by
For , we denote by .
Let be a subgroup of finite rank in (i.e., is finite-dimensional), and a subvariety of . Fix a basis of . If the set
is Zariski dense in for every positive number , then is a translation of an abelian subvariety of by an element of .
The proof of Theorem A.1 and Theorem A.2: Here, let us give the proof of Theorem A.1, Theorem A.2. Theorem A.1 is obvious by [5, Theorem 4.3] and Proposition 3.4.3, or Theorem 6.1.1. Theorem A.2 is a consequence of [6], Proposition 3.4.3 and the following lemma.
Lemma A.3.
Let be a vector space over , and and be two inner products on . If for all , then for all .
Proof. If are linearly dependent, then our assertion is trivial. Otherwise, it is nothing more than [4, Lemma 3.4].
Remark A.4.
In order to guarantee Northcott’s theorem, the fineness of a polarization is crucial. The following example shows us that even if the polarization is ample in the geometric sense, Northcott’s theorem does not hold in general.
Let , , and . We set
Then, is an abelian scheme over . Then, as in the proof of [5, Proposition 3.1.1], we can construct a nef -hermitian line bundle on such that and is ample on , is positive on , and that . Let be the function field of . Then, is a polarization of . Here we claim that Northcott’s theorem dose not hold for the polarization of .
Let be the projection to the -th factor. Then, considering , gives rise to a model of . Let be the graph of , i.e., . Moreover, let be a -valued point of arising from . Then, if we denote the section by , then
On the other hand, ’s are distinct points in .
Appendix B. Geometric Northcott’s theorem
Proposition B.1.
Let be a smooth projective variety over an algebraically closed field of characteristic zero, a smooth projective curve over , and a surjective morphism whose generic fiber is geometrically irreducible. Let be an ample line bundle on . If for some , then, for any number , the set
is not dense in .
Proof. Let us begin with the following lemma.
Lemma B.2.
Let be a surjective morphism of smooth projective varieties over an algebraically closed field of characteristic zero. If there are a projective smooth algebraic variety over and a dominant rational map over , then the double dual of is a free -sheaf for all .
Proof. Let be a very ample line bundle on . If and is a general member of , then still dominates . Thus, considering induction on , we may assume that .
Let be a birational morphism of smooth projective varieties such that is a morphism. Then, is generically finite. Thus, there is a natural injection . Hence, for all . Therefore,
Applying to the above injection, we have
Further, letting be the natural projection ,
Thus, is a subsheaf of the free sheaf .
Here we claim
| (B.2.1) |
where is an ample line bundle on and . This is an immediate consequence of weak positivity of due to Viehweg [8]. We can however conclude our claim by a weaker result of Kawamata [3], namely if . For, considering complete intersections by general members of (), we may assume .
We can find a projection such that and the composition
is injective. Therefore, since is reflexive, the above homomorphism is an isomorphism by (B.2.1).
Let us go back to the proof of Proposition B.1. Let be a scheme consisting of morphisms from to . Then, there is a morphism given by . We set . Then, there is a natural morphism given by . Since is ample,
is a bounded family, so that there are finitely many connected components of such that, for all sections with , there is for some with . On the other hand, by Lemma B.2, is not a dominant morphism for every . Thus, we get our proposition.
References
- [1] V. V. Batyrev and Yu. Manin, Sur le nombre de points rationnels de hauteur bornée des variétés algébriques, Math. Ann. 286 (1990), 27–43.
- [2] S. Kawaguchi and A. Moriwaki, Inequalities for semistable families for arithmetic varieties, J. Math. Kyoto Univ. 36, 97–182 (2001).
- [3] Y. Kawamata, Kodaira dimension of algebraic fiber spaces over curves, Invent. Math., 66 (1982), 57–71.
- [4] A. Moriwaki, Inequality of Bogomolov-Gieseker type on arithmetic surfaces, Duke Math. J. 74 (1994), 713–761.
- [5] A. Moriwaki, Arithmetic height functions over finitely generated fields, Invent. math., 140, (2000), 101–142.
- [6] A. Moriwaki, A generalization of conjectures of Bogomolov and Lang over finitely generated fields, Duke Math. J. 107, (2001), 85–102.
- [7] A. Moriwaki, The canonical arithmetic height of subvarieties of an abelian variety over a finitely generated field, J. reine angew. Math. 530 (2001), 33-54.
- [8] E. Viehweg, Die additivität der Kodaira dimension für projektive faserraüme über varietäten des allgemeinen typs, J. Reine Angew. Math., 330 (1982), 132–142.
- [9] D. Wan, Zeta functions of algebraic cycles over finite fields, manuscripta math. 74 (1992), 413–444.
- [10] D. B. Zagier, Zetafunktionen und quadratische Körper, Springer Verlag (1981).